@@ -358,7 +358,7 @@ conv_10(
     register u_long_int magnitude;
 
     if (is_unsigned) {
-        magnitude = (u_long_int) num;
+        magnitude = (u_long_int)num;
         *is_negative = FALSE;
     }
     else {
@@ -376,17 +376,16 @@ conv_10(
             magnitude = ((u_long_int) - t) + 1;
         }
         else
-            magnitude = (u_long_int) num;
+            magnitude = (u_long_int)num;
     }
     /* We use a do-while loop so that we write at least 1 digit */
     do {
         register u_long_int new_magnitude = magnitude / 10;
         *--p = (char) (magnitude - new_magnitude * 10 + '0');
         magnitude = new_magnitude;
-    }
-    while (magnitude);
-    *len = buf_end - p;
-    return (p);
+    } while (magnitude);
+    *len = (int)(buf_end - p);
+    return p;
 }
 
 static char *
@@ -401,7 +400,7 @@ conv_10_quad(
     u_quad_int magnitude;
 
     if (is_unsigned) {
-        magnitude = (u_quad_int) num;
+        magnitude = (u_quad_int)num;
         *is_negative = FALSE;
     }
     else {
@@ -418,17 +417,16 @@ conv_10_quad(
             magnitude = ((u_quad_int) - t) + 1;
         }
         else
-            magnitude = (u_quad_int) num;
+            magnitude = (u_quad_int)num;
     }
     /* We use a do-while loop so that we write at least 1 digit */
     do {
         u_quad_int new_magnitude = magnitude / 10;
         *--p = (char)(magnitude - new_magnitude * 10 + '0');
         magnitude = new_magnitude;
-    }
-    while (magnitude);
-    *len = buf_end - p;
-    return (p);
+    } while (magnitude);
+    *len = (int)(buf_end - p);
+    return p;
 }
 
 /*
@@ -516,8 +514,8 @@ conv_fp(
         }
     }
 
-    *len = s - buf;
-    return (buf);
+    *len = (int)(s - buf);
+    return buf;
 }
 
 /*
@@ -551,8 +549,8 @@ conv_p2(
         *--p = digits[num & mask];
         num >>= nbits;
     } while (num);
-    *len = buf_end - p;
-    return (p);
+    *len = (int)(buf_end - p);
+    return p;
 }
 
 static char *
@@ -571,8 +569,8 @@ conv_p2_quad(
         *--p = digits[num & mask];
         num >>= nbits;
     } while (num);
-    *len = buf_end - p;
-    return (p);
+    *len = (int)(buf_end - p);
+    return p;
 }
 
 /* 
@@ -1052,7 +1050,7 @@ int str_format_va(char *s, str_size_t n, const char *fmt, va_list ap)
         handle.data[2].i = sizeof(buf);
         rv = str_vformat(&handle, fmt, ap);
         if (rv == -1)
-            rv = n;
+            rv = (int)n;
     }
     else {
         /* real formatting, i.e., create output */
@@ -1063,7 +1061,7 @@ int str_format_va(char *s, str_size_t n, const char *fmt, va_list ap)
         rv = str_vformat(&handle, fmt, ap);
         *(handle.curpos) = NUL;
         if (rv == -1)
-            rv = n;
+            rv = (int)n;
     }
     return rv;
 }
@@ -1071,10 +1069,11 @@ int str_format_va(char *s, str_size_t n, const char *fmt, va_list ap)
 int str_format(char *s, str_size_t n, const char *fmt, ...)
 {
     va_list ap;
+    int rv;
 
     va_start(ap, fmt);
-    str_format_va(s, n, fmt, ap);
+    rv = str_format_va(s, n, fmt, ap);
     va_end(ap);
-    return 0;
+    return rv;
 }
 
