@@ -46,7 +46,7 @@ char *str_span(const char *s, str_size_t n, const char *charset, int mode)
     if (s == NULL || charset == NULL)
         return NULL;
     if (n == 0)
-        n = str_len(s);
+        str_ilen(n, s);
     rv = NULL;
     if (!(mode & STR_RIGHT) && !(mode & STR_COMPLEMENT)) {
         /* span from left to right while chars are in charset */
@@ -139,28 +139,19 @@ char *str_locate(const char *ay, str_size_t n, const char *ax)
     /*
      * Consistency checks
      */
-    if (ay == NULL || ax == NULL)
+    if (y == NULL || x == NULL)
         return NULL;
-    if (*ax == NUL)
-        return (char *)ay;
+    if (*x == NUL)
+        return (char *)y;
 
     /* 
      * Preprocessing
      */
 
-    /* length of y [inlined n = strlen(y)] */
-    if (n == 0) {
-        ty = y;
-        while (*ty++ != NUL)
-            /*nop*/;
-        n = (ty-y-1);
-    }
-
-    /* length of x [inlined m = strlen(x)] */
-    tx = x;
-    while (*tx++ != NUL)
-        /*nop*/;
-    m = (tx-x-1);
+    /* determine length of strings */
+    str_ilen(m, x);
+    if (n == 0) 
+        str_ilen(n, y);
 
     /* fill whole bad char skip array */
     for (i = 0; i < (sizeof(qs_bc)/sizeof(int)); i++) 
